/// <reference types="react" />
import * as _ from "lodash";
import { DiagramEngine } from "../DiagramEngine";
import { BaseAction } from "../actions/BaseAction";
import { BaseWidget, BaseWidgetProps } from "./BaseWidget";
export interface DiagramProps extends BaseWidgetProps {
    diagramEngine: DiagramEngine;
    allowLooseLinks?: boolean;
    maxNumberPointsPerLink?: number;
    connectors?: boolean;
    smartRouting?: boolean;
    rightAnglesRouting?: boolean;
    highlightPorts?: "none" | "valid" | "all";
    actionStartedFiring?: (action: BaseAction) => boolean;
    actionStillFiring?: (action: BaseAction) => void;
    actionStoppedFiring?: (action: BaseAction) => void;
    deleteKeys?: number[];
    drawMatrix?: boolean;
}
export interface DiagramState {
    action: BaseAction | null;
    wasMoved: boolean;
    renderedNodes: boolean;
    windowListener: any;
    diagramEngineListener: any;
    document: any;
    modelId: string;
}
/**
 * @author Dylan Vorster, Iliya Krastinkov
 *
 * Responsibility: Wire components hierarchy and events.
 */
export declare class DiagramWidget extends BaseWidget<DiagramProps, DiagramState> {
    static defaultProps: DiagramProps;
    private dispatcher;
    onKeyUpPointer: (this: any, ev: KeyboardEvent) => void;
    reattachEngineListener: ((diagramEngine: DiagramEngine) => void) & _.MemoizedFunction;
    constructor(props: DiagramProps);
    componentWillUnmount(): void;
    static getDerivedStateFromProps(props: any, state: any): any;
    componentDidUpdate(prevProps: Readonly<DiagramProps>, prevState: Readonly<DiagramState>, snapshot?: any): void;
    componentDidMount(): void;
    onKeyUp(event: any): void;
    drawSelectionBox(): JSX.Element;
    render(): JSX.Element;
}
